"""Metadata constants for injx package."""

__org__ = "QriusGlobal"
__author__ = "Qrius Global"
__email__ = "mishal@qrius.global"
__repo__ = "https://github.com/QriusGlobal/injx"
__docs__ = "https://qriusglobal.github.io/injx/"